/*
 * DemosceneMusic - AdminBasePage.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.page.admin;

import java.util.ArrayList;
import java.util.List;
import java.util.Map.Entry;

import net.pterodactylus.demoscenemusic.core.Core;
import net.pterodactylus.demoscenemusic.data.Base;
import net.pterodactylus.demoscenemusic.data.User;
import net.pterodactylus.demoscenemusic.page.BasePage;
import net.pterodactylus.demoscenemusic.page.ServletRequest;
import net.pterodactylus.util.template.Template;
import net.pterodactylus.util.template.TemplateContextFactory;

/**
 * Base page for all admin pages.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class AdminBasePage extends BasePage {

	/**
	 * Creates a new admin page.
	 *
	 * @param core
	 *            The core
	 * @param templateContextFactory
	 *            The template context factory
	 * @param template
	 *            The template to render
	 * @param pageName
	 *            The name of the page
	 */
	public AdminBasePage(Core core, TemplateContextFactory templateContextFactory, Template template, String pageName) {
		super(core, templateContextFactory, template, pageName);
	}

	//
	// PROTECTED METHODS
	//

	/**
	 * Processes properties from the given requests and adjusts the properties
	 * of the given object.
	 *
	 * @param request
	 *            The request to process
	 * @param object
	 *            The object whose properties to modify
	 */
	protected void processProperties(ServletRequest request, Base object) {
		/* check if properties were changed. */
		List<String> propertiesToDelete = new ArrayList<String>();
		for (Entry<String, String> property : object.getProperties()) {
			if (request.getServletRequest().getParameter("delete." + property.getKey()) != null) {
				propertiesToDelete.add(property.getKey());
				continue;
			}
			String value = request.getServletRequest().getParameter("value." + property.getKey()).trim();
			object.getProperties().set(property.getKey(), value);
		}

		/* check if properties are deleted. */
		if (!propertiesToDelete.isEmpty()) {
			for (String propertyToDelete : propertiesToDelete) {
				object.getProperties().remove(propertyToDelete);
			}
		}

		/* check for a new property. */
		if ("true".equals(request.getServletRequest().getParameter("new-property"))) {
			String property = request.getServletRequest().getParameter("property").trim();
			String value = request.getServletRequest().getParameter("value").trim();
			if ((property.length() > 0) && (value.length() > 0)) {
				object.getProperties().set(property, value);
			}
		}
	}

	//
	// BASEPAGE METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected int getRequiredUserLevel() {
		return User.LEVEL_GOD;
	}

}
